@@ -1,6 +1,6 @@
 from typing import AnyStr, Optional
 
-from .bidi import get_display_inner
+from .bidi import get_display_inner, get_base_level_inner
 
 
 def get_display(
@@ -12,9 +12,6 @@ def get_display(
     """Accepts string or bytes. In case of bytes, `encoding`
     is needed as the inner function expects a valid string (default:"utf-8").
 
-    Set `upper_is_rtl` to True to treat upper case chars as strong 'R'
-    for debugging (default: False).
-
     Set `base_dir` to 'L' or 'R' to override the calculated base_level.
 
     Set `debug` to True to return the calculated levels.
@@ -37,3 +34,11 @@ def get_display(
         display = display.encode(encoding)
 
     return display
+
+
+def get_base_level(text: str) -> int:
+    """Returns the base unicode level of the 1st paragraph in `text`.
+
+    Return value of 0 means LTR, while 1 means RTL.
+    """
+    return get_base_level_inner(text)
