@@ -80,15 +80,22 @@ class TestBidiAlgorithm(unittest.TestCase):
             self.assertEqual(get_display(storage), display)
 
     def test_compat(self):
-        """Test backword compat from import"""
+        """Test backward compat for import get_display"""
 
         from bidi.algorithm import get_display as get_display_compat
 
-        storage = f"{HELLO_HEB_LOGICAL}"
-        display = f"{HELLO_HEB_DISPLAY}"
+        storage = HELLO_HEB_LOGICAL
+        display = HELLO_HEB_DISPLAY
 
         self.assertEqual(get_display_compat(storage), display)
 
+    def test_get_base_level(self):
+        """Test base dir for backward comat"""
+
+        from bidi.algorithm import get_base_level
+        self.assertEqual(get_base_level(HELLO_HEB_LOGICAL), 1)
+        self.assertEqual(get_base_level("Hello"), 0)
+
 
 if __name__ == "__main__":
     unittest.main()
